<?php
namespace OnairElementor;

/**
 * Class Plugin
 *
 * Main Plugin class
 * @since 1.0.0
 */
class Plugin {
 
	/**
	 * Instance
	 *
	 * @since 1.0.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;
 
	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.2.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
					 
		return self::$_instance;
	}
 
	/**
	 * widget_scripts
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function widget_scripts() {
		// $deps = array('jquery', 'masonry');
		
	}

	/**
	 * enqueue_styles
	 *
	 * Load custom styling.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function enqueue_styles() {
		wp_enqueue_style( 'onair-elementor-admin', plugins_url( '/assets/css/admin.css', __FILE__ ) );
		wp_enqueue_style( 'onair-elementor-admin-icons', plugins_url( '/assets/font/onair-for-elementor/styles.css', __FILE__ ) );
		wp_enqueue_style(
			'elementor-editor-dark-mode',
			ELEMENTOR_ASSETS_URL . 'css/editor-dark-mode.css',
			[
				'elementor-editor',
			]
		);
	}


	/**
	 * Include Widgets files
	 *
	 * Load widgets files
	 *
	 * @since 1.2.0
	 * @access private
	 */
	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/_helpers/autocomplete.php' );
		require_once( __DIR__ . '/widgets/_helpers/converter.php' );
		require_once( __DIR__ . '/widgets/_helpers/get-terms-array.php' );
		require_once( __DIR__ . '/widgets/_helpers/query-fields.php' );
		require_once( __DIR__ . '/widgets/_helpers/carousel-fields.php' );
		require_once( __DIR__ . '/widgets/_helpers/items-design-fields.php' );
		require_once( __DIR__ . '/widgets/_helpers/slider-fields.php' );
		require_once( __DIR__ . '/widgets/appicons/appicons.php' );
		require_once( __DIR__ . '/widgets/sponsors/sponsors.php' );
		require_once( __DIR__ . '/widgets/button/button.php' );
		require_once( __DIR__ . '/widgets/caption/caption.php' );
		require_once( __DIR__ . '/widgets/chart-tracklist/chart-tracklist.php' );
		require_once( __DIR__ . '/widgets/post-large/post-large.php' );
		require_once( __DIR__ . '/widgets/post-list/post-list.php' );
		require_once( __DIR__ . '/widgets/post-cards/post-cards.php' );
		require_once( __DIR__ . '/widgets/post-grid/post-grid.php' );
		require_once( __DIR__ . '/widgets/post-hero/post-hero.php' );
		require_once( __DIR__ . '/widgets/post-carousel/post-carousel.php' );
		require_once( __DIR__ . '/widgets/post-slider/post-slider.php' );
		require_once( __DIR__ . '/widgets/event-list/event-list.php' );
		require_once( __DIR__ . '/widgets/event-featured/event-featured.php' );
		require_once( __DIR__ . '/widgets/onair/onair.php' );
		require_once( __DIR__ . '/widgets/upcoming-shows-carousel/upcoming-shows-carousel.php' );
		require_once( __DIR__ . '/widgets/upcoming-shows-slider/upcoming-shows-slider.php' );
		require_once( __DIR__ . '/widgets/show-onair-mini/show-onair-mini.php' );
		require_once( __DIR__ . '/widgets/show-upcoming-mini/show-upcoming-mini.php' );
		require_once( __DIR__ . '/widgets/schedule/schedule.php' );
		require_once( __DIR__ . '/widgets/sharing/sharing.php' );
		require_once( __DIR__ . '/widgets/qt-video/qt-video.php' );
		require_once( __DIR__ . '/widgets/radiofeed/radiofeed.php' );
		require_once( __DIR__ . '/widgets/artwork/artwork.php' );
		require_once( __DIR__ . '/widgets/cf7/cf7.php' );
	}
 
	/**
	 * Register Widgets
	 *
	 * Register new Elementor widgets.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function register_widgets() {
		// Register Widgets
		$this->include_widgets_files();
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorAppIcons() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorButton() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorCaption() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorSponsors() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorChartTracklist() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorPostLarge() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorPostList() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorPostCards() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorPostGrid() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorPostHero() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorPostCarousel() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorPostSlider() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorEventList() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorEventFeatured() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorOnair() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorUpcomingShowsCarousel() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorUpcomingShowsSlider() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorShowOnairMini() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorShowUpcomingMini() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorSchedule() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorSharing() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorQtVideo() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorRadiofeed() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorArtwork() );
		if(defined('WPCF7_VERSION')){
			\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\OnairElementorCF7() );
		}
	}

	public function add_elementor_widget_categories($elements_manager ) {
		\Elementor\Plugin::instance()->elements_manager->add_category(
			'OnAir',
			[
				'title' => esc_html__( 'OnAir ', 'plugin-name' ),
				'icon' => 'fa fa-plug',
			]
		);
	}

	public function order_elementor_widget_categories(\Elementor\Elements_Manager $elements_manager ) {
		$category_prefix = 'aaa-';
		$elements_manager->add_category(
			$category_prefix . 'onair',
			[
				'title' => esc_html__( 'OnAir ', 'plugin-name' ),
				'icon' => 'fa fa-plug',
			]
		);
		//hack into the private $categories member, and reorder it so our stuff is at the top
		$reorder_cats = function() use($category_prefix){
			uksort($this->categories, function($keyOne, $keyTwo) use($category_prefix){
				if(substr($keyOne, 0, 4) == $category_prefix){
					return -1;
				}
				if(substr($keyTwo, 0, 4) == $category_prefix){
					return 1;
				}
				return 0;
			});

		};
		$reorder_cats->call($elements_manager);
	}

	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function __construct() {
		//Add category
		add_action( 'elementor/elements/categories_registered', [ $this, 'add_elementor_widget_categories' ], 0 );
		add_action( 'elementor/elements/categories_registered', [ $this, 'order_elementor_widget_categories' ], 0 );
		// Register widget scripts
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'widget_scripts' ] );
		// Register widgets
		add_action( 'elementor/widgets/register', [ $this, 'register_widgets' ] );
		// custom styling
		add_action('elementor/editor/before_enqueue_scripts', [ $this, 'enqueue_styles' ] );
	}
}
 
// Instantiate Plugin Class
Plugin::instance();

