<?php 
/**
 * @package OnAir Elementor
 * 
 * Admin Settings
 * 
 * */

if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

if ( ! function_exists( 'onairelementor_settings_page_menu' ) ) {
	add_action( 'admin_menu', 'onairelementor_settings_page_menu' );
	function onairelementor_settings_page_menu() {
		add_menu_page(
			esc_html__( 'OnAir Elementor', 'onair-elementor' ),
			esc_html__( 'OnAir Elementor', 'onair-elementor' ),
			'manage_options',
			'onairelementor-settings-page',
			'onairelementor_settings_page',
			get_theme_file_uri('/img/icon-qt.png' ),
			2 // Order ID
		);
	
	}	
}




if(!function_exists('onairelementor_settings_page')){

	function onairelementor_settings_page() {

		/**
		 *  We check if the use is qualified enough
		 */
		$user = wp_get_current_user();
		$allowed_roles = array( 'administrator' );
		if (!current_user_can('manage_options') || !array_intersect($allowed_roles, $user->roles ) )  {
			wp_die( esc_html__('You do not have sufficient permissions to access this page.' , 'onair-elementor') );
		}



		/**
		 * ======================================================================================
		 * 
		 * Form fields
		 * 
		 * ======================================================================================
		 * */
		
		$controls = array();

		// Registration
		$controls[] = array(
			'id' => 'onairelementor-purchase-code',
			'type'	=> 'license_key',
			'default' => false,
			'label'	=> esc_html__('Purchase code for OnAir2', 'onair-elementor'),
			'description'	=> esc_html__('Where is my purchase code?', 'onair-elementor').' https://help.market.envato.com/hc/en-us/articles/202822600-Where-Is-My-Purchase-Code- ',
		);

		/**
		 * =====================================================
		 * Form ouput
		 * =====================================================
		 * */
		if(function_exists('onairelementor_form_generator')){
			$nonce_action = 'onairelementor_settings_save';
			$nonce_name = 'onairelementor_settings_nonce';
			$title = esc_html__("Global settings", "onair-elementor");
			// echo get_option( 'onairelementor_k_'. qtt_iid( true ) , false ); // helps against thefts;
			?>
				<div class="onairelementor onairelementor_settings-framework onairelementor_settings-optionspage">
					<?php include 'header.php'; ?>

					<?php

					/**
					 * =====================================================
					 * Form
					 * =====================================================
					 * */
					onairelementor_form_generator( $title, $controls, $nonce_action , $nonce_name); 

					?>
				<p>The license code can be used only on 1 development local website and 1 online website. The current domain and code will be stored in our database. To change the domain associated with your code please contact our helpdesk.</p>
				</div>

			<?php 

			$exp = [
				'elementor_experiment-e_optimized_assets_loading',
				'elementor_experiment-e_optimized_css_loading',
				'elementor_experiment-e_font_icon_svg',
				'elementor_experiment-additional_custom_breakpoints',
				'elementor_experiment-e_hidden_wordpress_widgets',
				'elementor_experiment-e_dom_optimization',
				'elementor_experiment-a11y_improvements',
				'elementor_experiment-admin-top-bar',
				'elementor_experiment-container'
			];
			foreach($exp as $e){
				update_option( $e, 'inavtive');
			}
		}
		return;	
	}
}

/**
 * =====================================================
 * End of file
 * =====================================================
 * */




