<?php
/**
 * @package WordPress
 * @subpackage onair
 * @version 1.1.4
*/

namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;


add_action('elementor/element/before_section_end', function( $section, $section_id, $args ) {


	if( $section_id == 'Onair_Elementor_section_query_global' ){
			$section->add_control(
				'include_by_id',
				[
					'label' => esc_html__( 'Posts by ID, comma separated list of numeric IDs', 'onair-elementor' ),
					'description' => esc_html__("Display only the contents with these IDs. All other parameters will be ignored.", 'onair-elementor'),
					'type' => Controls_Manager::TEXT,
					'label_block' => true
				]
			);
			$section->add_control(
				'items_per_page',
				[
					'label' => esc_html__( 'Max items', 'onair-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'min' => 1,
					'max' => 100,
					'step' => 1,
					'default' => 5,
				]
			);
			
			$section->add_control(
				'orderby',
				[
					'label' => esc_html__( 'Order by', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						'date' => esc_html__( 'Date', 'onair-elementor' ),
						'ID' => esc_html__( 'Post ID', 'onair-elementor' ),
						'author' => esc_html__( 'Author', 'onair-elementor' ),
						'title' => esc_html__( 'Title', 'onair-elementor' ),
						'modified' => esc_html__( 'Last modified date', 'onair-elementor' ),
						'parent' => esc_html__( 'Post/page parent ID', 'onair-elementor' ),
						'comment_count' => esc_html__( 'Number of comments', 'onair-elementor' ),
						'menu_order' => esc_html__( 'Menu order', 'onair-elementor' ),
						'meta_value' => esc_html__( 'Meta value', 'onair-elementor' ),
						'rand' => esc_html__( 'Random', 'onair-elementor' ),
					],
				]
			);
			$section->add_control(
				'order',
				[
					'label' => esc_html__( 'Order', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						'DESC' => esc_html__( 'Descending', 'onair' ),
						'ASC' => esc_html__( 'Ascending', 'onair' ),
					],
				]
			);
			$section->add_control(
				'meta_key',
				[
					'label' => esc_html__( 'Meta key', 'onair-elementor' ),
					'description' => esc_html__("Order based on this meta key", 'onair-elementor'),
					'type' => Controls_Manager::TEXT,
					'condition' => [
						'orderby' => 'meta_value',
					],
				]
			);
			$section->add_control(
				'offset',
				[
					'label' => esc_html__( 'Offset', 'onair-elementor' ),
					'description' => esc_html__('Number of grid elements to displace or pass over.', 'onair-elementor'),
					'type' => Controls_Manager::TEXT,
				]
			);
			$section->add_control(
				'exclude',
				[
					'label' => esc_html__( 'Exclude', 'onair-elementor' ),
					'description' => esc_html__('Comma-separated list of IDs to exclude', 'onair-elementor'),
					'type' => Controls_Manager::TEXT,
				]
			);
	}
}, 10, 3 );