<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Qantum Themes SL
 * @package  Elementor OnAir
 * @version  1.0.0
 */


namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class OnairElementorAppIcons extends Widget_Base {
	public function get_name() {
		return 'onair-elementor-qt-appicons'; // need to use same ID in the script js
	}
	public function get_title() {
		return __( 'Streaming App Icons', 'onair-elementor' );
	}
	public function get_icon() {
		return 'onair-elementor-icons icon-prel-streaming-app-icons';
	}
	public function get_categories() {
		return [ 'aaa-onair' ]; // needs to be registered in _plugin.php
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_icons',
			[
				'label' => __( 'Icons', 'onair-elementor' ),
			]
		);
			$this->add_control(
				'app_alexa',
				[
					'label' => esc_html__( 'Alexa', 'onair-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_android',
				[
					'label' => esc_html__( 'Android', 'onair-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_iphone',
				[
					'label' => esc_html__( 'iPhone', 'onair-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_blackberry',
				[
					'label' => esc_html__( 'Blackberry', 'onair-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_itunes',
				[
					'label' => esc_html__( 'iTunes', 'onair-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_winphone',
				[
					'label' => esc_html__( 'Windows', 'onair-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_winamp',
				[
					'label' => esc_html__( 'WinAmp', 'onair-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_tunein',
				[
					'label' => esc_html__( 'TuneIn', 'onair-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_mediaplayer',
				[
					'label' => esc_html__( 'Media Player', 'onair-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			
		$this->end_controls_section();


		$this->start_controls_section(
			'onair_section_button_design',
			[
				'label' => esc_html__( 'Design', 'elementor-onair' ),
			]
		);

			$this->add_responsive_control(
				'btn-size',
				[
					'label' => esc_html__( 'Size', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 120,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors' => [
						'{{WRAPPER}} .onair-btn' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);
			$this->add_responsive_control(
				'icon-size',
				[
					'label' => esc_html__( 'Icon size', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 120,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors' => [
						'{{WRAPPER}} .onair-btn span' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};background-size: {{SIZE}}{{UNIT}} {{SIZE}}{{UNIT}};',
					],
				]
			);
			

			$this->add_responsive_control(
				'pr_padding',
				[
					'label' => __( 'Padding', 'kentha-elementor' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'default' =>[
						'isLinked' => false,
						],
					'selectors' => [
						'{{WRAPPER}} .onair-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
					],
				]
			);


			$this->add_responsive_control(
				'btn-radius',
				[
					'label' => esc_html__( 'Border-radius', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 300,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors' => [
						'{{WRAPPER}} .onair-btn' => 'border-radius: {{SIZE}}{{UNIT}};',
					],
				]
			);
		$this->end_controls_section();

		/**
		 * Colors
		 */
		$this->start_controls_section(
			'section_button_col',
			[
				'label' => esc_html__( 'Colors', 'elementor-onair' ),
			]
		);
			$this->add_control(
				'onair-btn-bg',
				[
					'label' => esc_html__( 'Background', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .onair-btn' => 'background: {{VALUE}} !important;',
					],
				]
			);
	

			

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'onair-btn-border',
					'label' => __( 'Border', 'plugin-domain' ),
					'selector' => '{{WRAPPER}} .onair-btn',
				]
			);

			

		$this->end_controls_section();

		/**
		 * Colors hover
		 */
		$this->start_controls_section(
			'section_button_col_h',
			[
				'label' => esc_html__( 'Colors hover', 'elementor-onair' ),
			]
		);
			$this->add_control(
				'onair-btn-bgh',
				[
					'label' => esc_html__( 'Background hover', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .onair-btn:hover, {{WRAPPER}} .onair-btn:hover::after' => 'background: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'onair-btn-bch',
				[
					'label' => esc_html__( 'Border hover', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .onair-btn:hover' => 'border-color: {{VALUE}} !important;',
					]
				]
			);
			

		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		
		$atts = $this->get_settings_for_display();
		$icons = array(
			'app_alexa' ,
			'app_android',
			'app_iphone' ,
			'app_blackberry',
			'app_itunes' ,
			'app_winphone',
			'app_winamp' ,
			'app_tunein' ,
			'app_mediaplayer'
		);

		?>
		<p class="qt-center">
			<?php  
			foreach($icons as $i){
				if(array_key_exists($i, $atts) && $atts[$i] != ''){
					?>
					<a href="<?php echo esc_attr( $atts[ $i ] ); ?>" class="onair-btn qt-btn qt-btn-primary qt-btn-l qt-appicon noajax"><span class="qt-<?php echo esc_attr( $i ); ?>"></span></a>
					<?php  
				}
			}
			?>
		</p>
		<?php
	}

	
	protected function content_template() {}
}