<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Qantum Themes SL
 * @package  Elementor OnAir
 * @version  PR.2.1.2 
 */


namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class OnairElementorArtwork extends Widget_Base {
	public function get_name() {
		return 'onair-elementor-artwork'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Song artwork', 'elementor-onair' );
	}
	public function get_icon() {
		return 'onair-elementor-icons icon-prel-shows-onair';
	}
	public function get_categories() {
		return [ 'aaa-onair' ]; // needs to be registered in _plugin.php
	}

		/**
	 * @since version PR.2.3.0 loaded from minified scripts.
	 * To unse unminified, edit _plugin.php line 53 $use_minified_script = true;
	 * 
	 * 
	 * */
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'onair-elementor-artwork', plugins_url( '/artwork.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'onair-elementor-artwork' ];
	}
	protected function register_controls() {
		$this->start_controls_section(
			'section_settings',
			[
				'label' => esc_html__( 'Settings', 'elementor-onair' ),
			]
		);
			$this->add_responsive_control(
				'onair-size',
				[
					'label' => esc_html__( 'Size', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 20,
							'max' => 1000,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 200,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 200,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 200,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .onair-artwork img ' => 'display: block;width: {{SIZE}}{{UNIT}};width: {{SIZE}}{{UNIT}};   object-fit: cover;',				
					],
				]
			);

			$this->add_responsive_control(
				'onair-radius',
				[
					'label' => esc_html__( 'Border radius', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 500,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 5,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 5,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 5,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .onair-artwork img  ' => 'border-radius: {{SIZE}}{{UNIT}};',
					],
				]
			);
			
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		?>
		<div class="onair-elementor onair-hidden onair-elementor--artwork onair-artwork">
			<a class="onair-inline onair-elementor--artwork__img " href="#">
			
			</a>
		</div>
		<?php
	}
	
	protected function content_template() {}
}