<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Qantum Themes SL
 * @package  Elementor OnAir
 * @version  2.0.1
 */


namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Control_Dimensions;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


include( __DIR__ . '/function-button.php' );

class OnairElementorButton extends Widget_Base {
	public function get_name() {
		return 'onair-elementor-button'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'OnAir Button', 'elementor-onair' );
	}
	public function get_icon() {
		return 'onair-elementor-icons icon-prel-button';
	}
	public function get_categories() {
		return [ 'aaa-onair' ]; // needs to be registered in _plugin.php
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_button',
			[
				'label' => esc_html__( 'Button', 'elementor-onair' ),
			]
		);
			
			$this->add_control(
				'text',
				[
					'label' => esc_html__( 'Button label', 'elementor-onair' ),
					'type' => Controls_Manager::TEXT,
				]
			);

			$this->add_control(
				'playradio',
				[
					'label' => esc_html__( 'Play radio channel', 'onair-elementor' ),
					'type' => Controls_Manager::SWITCHER,
					'return_value' => '1',
					// 'default' => '0',
				]
			);

			$this->add_control(
				'radio_id',
				[
					'label' => esc_html__( 'Play a radio channel on click', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => false,
					'options' => elementor_onair_autocomplete('radiochannel'),
					'condition' => [
						'playradio' => '1',
					],
				]
			);


			$this->add_control(
				'link',
				[
					'label' => esc_html__( 'Link', 'elementor-onair' ),
					'type' => Controls_Manager::TEXT,
					'condition' => [
						'playradio!' => '1',
					],
				]
			);


			$this->add_control(
				'btn_size',
				[
					'label' => esc_html__( 'Button size', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'qt-btn-m',
					'options' =>[
						'qt-btn-s' => esc_html__('Small', 'elementor-onair'),
						'qt-btn-m' => esc_html__('Default', 'elementor-onair'),
						'qt-btn-l' => esc_html__('Big', 'elementor-onair')
					]
				]
			);

			
			
			$this->add_control(
				'target',
				[
					'label' => esc_html__( 'Button target', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'condition' => [
						'playradio!' => '1',
					],
					'options' =>[
						'' => esc_html__('Default', 'elementor-onair'),
						'_blank' => esc_html__('New tab', 'elementor-onair'),
						'popup' => esc_html__('Popup', 'elementor-onair')
					]
				]
			);

			$this->add_responsive_control(
				'popup_w',
				[
					'label' => __( 'Popup width', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 180,
							'max' => 1600,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => 300,
					],
					'devices' => [ 'desktop' ],
			
					'conditions' => [
						'relation' => 'and',
						'terms' => [
							[
								'name' => 'target',
								'operator' => '==',
								'value' => 'popup'
							],
							[
								'name' => 'playradio',
								'operator' => '!=',
								'value' => '1'
							]
						]
					]
				]
			);
			$this->add_responsive_control(
				'popup_h',
				[
					'label' => __( 'Popup height', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 180,
							'max' => 1600,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => 300,
					],
					'devices' => [ 'desktop' ],
					'conditions' => [
						'relation' => 'and',
						'terms' => [
							[
								'name' => 'target',
								'operator' => '==',
								'value' => 'popup'
							],
							[
								'name' => 'playradio',
								'operator' => '!=',
								'value' => '1'
							]
						]
					]
				]
			);

			$this->add_control(
				'btn_style',
				[
					'label' => esc_html__( 'Style', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						"qt-btn-default" 	=> 	esc_html__( "Default","elementor-onair"),
						"qt-btn-primary" 	=> 	esc_html__( "Primary","elementor-onair"),
						"qt-btn-secondary" 	=> 	esc_html__( "Secondary","elementor-onair"),
						"qt-btn-ghost" 	=> 	esc_html__( "Ghost","elementor-onair"),
					]
				]
			);

			$this->add_control(
				'btn_alignment',
				[
					'label' => esc_html__( 'Alignment', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						'' => esc_html__( "Default", "onair"),
						'alignleft' 	=>	esc_html__( "Left", "elementor-onair"),
						'alignright'	=>	esc_html__( "Right", "elementor-onair"),
						'aligncenter'	=>	esc_html__( "Center", "elementor-onair"),
					]
				]
			);
			$this->add_control(
				'css_class',
				[
					'label' => esc_html__( 'CSS Class', 'elementor-onair' ),
					'type' => Controls_Manager::TEXT,
				]
			);
		$this->end_controls_section();


		

	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		
		onair_template_button($atts);

	}
	
	protected function content_template() {}
}