<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Qantum Themes SL
 * @package  Elementor OnAir
 * @version  1.0.0
 */


namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class OnairElementorCaption extends Widget_Base {
	public function get_name() {
		return 'onair-elementor-qt-caption'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Caption', 'onair-elementor' );
	}
	public function get_icon() {
		return 'onair-elementor-icons icon-prel-caption';
	}
	public function get_categories() {
		return [ 'aaa-onair' ]; // needs to be registered in _plugin.php
	}
		

	protected function register_controls() {
		$this->start_controls_section(
			'section_icons',
			[
				'label' => esc_html__( 'Caption', 'onair-elementor' ),
			]
		);
			
			
			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Caption', 'onair-elementor' ),
					'type' => Controls_Manager::TEXT
				]
			);
			
			$this->add_control(
				'caption_size',
				[
					'label' => esc_html__( 'Size', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'd',
					'options' =>[
						"d" => esc_html__( "Default", 'onair-elementor' ),
						"s" =>	esc_html__( "Smaller", 'onair-elementor' ),
					]
				]
			);
			
			$this->add_control(
				'cssclass',
				[
					'label' => esc_html__( 'CSS Class', 'onair-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);

			$this->add_control(
				'caption-bg',
				[
					'label' => esc_html__( 'Background', 'elementor-proradio' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .onair-caption span' => 'background-color: {{VALUE}} !important;',
						'{{WRAPPER}} .onair-caption' => 'border-color: {{VALUE}} !important;',
					],
				]
			);
			$this->add_control(
				'caption-txt',
				[
					'label' => esc_html__( 'Text color', 'elementor-proradio' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .onair-caption span' => 'color: {{VALUE}} !important;',
					]
				]
			);
			
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if($atts['caption_size'] =='d'){
			?>
			<h3 class="onair-caption qt-caption-med qt-capfont <?php echo esc_attr( $atts['cssclass'] ); ?>"><span><?php echo esc_html($atts['title']); ?></span></h3>
			<?php
		} else if($atts['caption_size'] =='s'){
			?>
			<h5 class="onair-caption qt-caption-small qt-capfont <?php echo esc_attr( $atts['cssclass'] ); ?>"><span><?php echo esc_html($atts['title']); ?></span></h5>
			<?php  
		}
	}
	
	protected function content_template() {}
}