<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Qantum Themes SL
 * @package  Elementor OnAir
 * @version  PR.2.0.7
 */


namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class OnairElementorChartTracklist extends Widget_Base {
	public function get_name() {
		return 'onair-elementor-chart-tracklist'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Chart tracklist', 'onair-elementor' );
	}
	public function get_icon() {
		return 'onair-elementor-icons icon-prel-chart-tracklist';
	}
	public function get_categories() {
		return [ 'aaa-onair' ]; // needs to be registered in _plugin.php
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_settings',
			[
				'label' => esc_html__( 'Settings', 'onair-elementor' ),
			]
		);	

			$this->add_control(
				'tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => Onair_Elementor_get_terms_array('chartcategory')
				]
			);
			$this->add_control(
				'chart_id',
				[
					'label' => esc_html__( 'Select chart', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'description' => esc_html__( "If not specified, use the first result", "onairelementor" ),
					'multiple' => false,
					'options' => elementor_onair_autocomplete('chart')
				]
			);
			$this->add_control(
				'number',
				[
					'label' => esc_html__( "Number of tracks to display", "onair" ),
					'description' => esc_html__( "If smaller than the chart tracks, a button to the chart page will appear.", "onairelementor" ),
					'type' => Controls_Manager::TEXT,
					'default' => 100
				]
			);
			$this->add_control(
				'showtitle',
				[
					'label' => esc_html__( "Show chart title", "onair" ),
					'type' => Controls_Manager::SWITCHER,
				]
			);
			$this->add_control(
				'showthumbnail',
				[
					'label' => esc_html__( "Display featured image", "onair" ),
					'type' => Controls_Manager::SWITCHER,
				]
			);
			$this->add_control(
				'chartstyle',
				[
					'label' => esc_html__( 'Chart style', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => "chart-normal",
					'options' =>[
						"chart-normal" => esc_html__( "Default", "onairelementor"),
						"chart-small" => esc_html__( "Compact", "onairelementor")
					]
				]
			);
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('tax_filter', $atts)){
			if(is_array($atts['tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['tax_filter']);
			}
		}
		if(function_exists('qantumthemes_chart_tracklist')){
			echo qantumthemes_chart_tracklist( $atts );
		}
	}
	protected function content_template() {}
}