<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Qantum Themes SL
 * @package  Elementor OnAir
 * @version  1.0.0
 */


namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class OnairElementorEventFeatured extends Widget_Base {
	public function get_name() {
		return 'onair-elementor-event-featured'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Event featured', 'onair-elementor' );
	}
	public function get_icon() {
		return 'onair-elementor-icons icon-prel-event-featured';
	}
	public function get_categories() {
		return [ 'aaa-onair' ]; // needs to be registered in _plugin.php
	}

	// Javascript
		/**
	 * @since version PR.2.3.0 loaded from minified scripts.
	 * To unse unminified, edit _plugin.php line 53 $use_minified_script = true;
	 * 
	 * 
	 * */
	public function __construct($data = [], $args = null) {
	  parent::__construct($data, $args);
	  wp_register_script( 'onair-elementor-event-featured', plugins_url( '/event-featured.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
	}
	public function get_script_depends() {
		 return [ 'onair-elementor-event-featured' ];
	}

	protected function register_controls() {
		$this->start_controls_section(
			'Onair_Elementor_section_query_events',
			[
				'label' => esc_html__( 'Query', 'onair-elementor' ),
			]
		);	

			$this->add_control(
				'include_by_id',
				[
					'label' => esc_html__( 'Specific items by title', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => false,
					'options' => elementor_onair_autocomplete('event')
				]
			);

	
			$this->add_control(
				'tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => Onair_Elementor_get_terms_array('eventtype'),
				]
			);
			$this->add_control(
				'tax_filter_exc',
				[
					'label' => esc_html__( 'Exclude by category', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => Onair_Elementor_get_terms_array('eventtype')
				]
			);
			$this->add_control(
				'hideold',
				[
					'label' => esc_html__( 'Hide old events', 'onair-elementor' ),
					'type' => Controls_Manager::SWITCHER,
					'return_value' => 'true',
				]
			);
			$this->add_control(
				'countdown',
				[
					'label' => esc_html__( 'Countdown', 'onair-elementor' ),
					'type' => Controls_Manager::SWITCHER,
					'default' => false,
					'return_value' => 'true',
				]
			);
			
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		$atts['onair_elementor'] = true;
		if(array_key_exists('tax_filter', $atts)){
			if(is_array($atts['tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['tax_filter']);
			}
		}
		if(array_key_exists('tax_filter_exc', $atts)){
			if(is_array($atts['tax_filter_exc'])) {
				$atts['tax_filter_exc'] = implode(',', $atts['tax_filter_exc']);
			}
		}

		if(function_exists('qantumthemes_event_featured')){
			echo qantumthemes_event_featured( $atts );
		}
	}
	protected function content_template() {}
}