<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Qantum Themes SL
 * @package  Elementor OnAir
 * @version  1.0.0
 */


namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class OnairElementorOnair extends Widget_Base {
	public function get_name() {
		return 'onair-elementor-onair'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Show On Air', 'elementor-onair' );
	}
	public function get_icon() {
		return 'onair-elementor-icons icon-prel-shows-onair';
	}
	public function get_categories() {
		return [ 'aaa-onair' ]; // needs to be registered in _plugin.php
	}


	public function __construct($data = [], $args = null) {
	  parent::__construct($data, $args);
	  wp_register_script( 'onair-elementor-onair', plugins_url( '/onair.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
	}
	public function get_script_depends() {
		 return [ 'onair-elementor-onair' ];
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_settings',
			[
				'label' => esc_html__( 'Settings', 'elementor-onair' ),
			]
		);
			
			$this->add_control(
				'tax_filter',
				[
					'label' => esc_html__( 'Schedule filter', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'options' => Onair_Elementor_get_terms_array('schedulefilter')
				]
			);


			
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();

		$atts['onair_elementor'] = true;

		if(array_key_exists('tax_filter', $atts)){
			if(is_array($atts['tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['tax_filter']);
			}
		}
		
		if(function_exists('qantumthemes_onair')){
			echo qantumthemes_onair( $atts );
		}
	}
	
	protected function content_template() {}
}