<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Qantum Themes SL
 * @package  Elementor OnAir
 * @version  1.0.0
 */


namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class OnairElementorPostCards extends Widget_Base {
	public function get_name() {
		return 'onair-elementor-post-cards'; 
	}
	public function get_title() {
		return esc_html__( 'Post cards', 'onair-elementor' );
	}
	public function get_icon() {
		return 'onair-elementor-icons icon-prel-post-glass-cards';
	}
	public function get_categories() {
		return [ 'aaa-onair' ]; 
	}

	// Javascript =======================================
	public function __construct($data = [], $args = null) {
		parent::__construct($data, $args);
		wp_register_script( 'onair-elementor-post-cards', plugins_url( '/post-cards.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
	}
	public function get_script_depends() {
		 return [ 'onair-elementor-post-cards' ];
	}

	// Fields  =======================================
	protected function register_controls() {
		$this->start_controls_section(
			'Onair_Elementor_section_query_global',
			[
				'label' => esc_html__( 'Query', 'onair-elementor' ),
			]
		);


			$this->add_control(
				'posttype',
				[
					'label' => esc_html__( 'Columns', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'post',
					'options' =>[
						'post' => esc_html__( "Post", "onairelementor"),
						'members' => esc_html__( "Members", "onairelementor"),
						'podcast' => esc_html__( "Podcast", "onairelementor"),
						'radiochannel' => esc_html__( "Radio channel", "onairelementor"),
					]
				]
			);

			
			$this->add_control(
				'itemsperrow',
				[
					'label' => esc_html__( 'Columns', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 4,
					'options' =>[
						1 => esc_html__( "1", "onairelementor"),
						2 => esc_html__( "2", "onairelementor"),
						3 => esc_html__( "3", "onairelementor"),
						4 => esc_html__( "4", "onairelementor"),
					]
				]
			);
			
			$this->add_control(
				'tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => Onair_Elementor_get_terms_array()
				]
			);
			$this->add_control(
				'tax_filter_exc',
				[
					'label' => esc_html__( 'Exclude by category', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => Onair_Elementor_get_terms_array()
				]
			);

			$this->add_responsive_control(
				'onair-captionsize',
				[
					'label' => esc_html__( 'Caption size', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 15,
							'max' => 90,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors' => [
						'{{WRAPPER}} .qt-title  ' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);
		// Fields added by query-fields.php
		$this->end_controls_section();
	}
	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('tax_filter', $atts)){
			if(is_array($atts['tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['tax_filter']);
			}
		}
		if(array_key_exists('tax_filter_exc', $atts)){
			if(is_array($atts['tax_filter_exc'])) {
				$atts['tax_filter_exc'] = implode(',', $atts['tax_filter_exc']);
			}
		}

		if(function_exists('qantumthemes_post_cards')){
			echo qantumthemes_post_cards( $atts );
		}
	}
	protected function content_template() {}
}