<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Qantum Themes SL
 * @package  Elementor OnAir
 * @version  1.0.0
 */


namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class OnairElementorPostGrid extends Widget_Base {
	public function get_name() {
		return 'onair-elementor-post-grid'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Post or pages grid', 'onair-elementor' );
	}
	public function get_icon() {
		return 'onair-elementor-icons icon-prel-post-grid';
	}
	public function get_categories() {
		return [ 'aaa-onair' ]; // needs to be registered in _plugin.php
	}
	// Javascript =======================================
	public function __construct($data = [], $args = null) {
		parent::__construct($data, $args);
		wp_register_script( 'onair-elementor-post-grid', plugins_url( '/post-grid.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
	}
	public function get_script_depends() {
		 return [ 'onair-elementor-post-grid' ];
	}
	protected function register_controls() {
		$this->start_controls_section(
			'Onair_Elementor_section_query_global',
			[
				'label' => esc_html__( 'Query', 'onair-elementor' ),
			]
		);
			

			$this->add_control(
				'itemsperrow',
				[
					'label' => esc_html__( 'Columns', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 4,
					'options' =>[
						1 => esc_html__( "1", "onairelementor"),
						2 => esc_html__( "2", "onairelementor"),
						3 => esc_html__( "3", "onairelementor"),
						4 => esc_html__( "4", "onairelementor"),
					]
				]
			);
			

			$this->add_control(
				'tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => Onair_Elementor_get_terms_array('category')
				]
			);


			$this->add_control(
				'tax_filter_exc',
				[
					'label' => esc_html__( 'Exclude by category', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => Onair_Elementor_get_terms_array('category')
				]
			);

		// Fields added by query-fields.php
		$this->end_controls_section();





	}
	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('tax_filter', $atts)){
			if(is_array($atts['tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['tax_filter']);
			}
		}
		if(array_key_exists('tax_filter_exc', $atts)){
			if(is_array($atts['tax_filter_exc'])) {
				$atts['tax_filter_exc'] = implode(',', $atts['tax_filter_exc']);
			}
		}

		if(function_exists('qantumthemes_post_grid')){
			echo qantumthemes_post_grid( $atts );
		}
	}
	protected function content_template() {}
}