<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Qantum Themes SL
 * @package  Elementor OnAir
 * @version  1.0.0
 */


namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class OnairElementorPostInline extends Widget_Base {
	public function get_name() {
		return 'onair-elementor-post-inline'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Post inline', 'onair-elementor' );
	}
	public function get_icon() {
		return 'onair-elementor-icons icon-prel-post-list';
	}
	public function get_categories() {
		return [ 'aaa-onair' ]; // needs to be registered in _plugin.php
	}

	protected function register_controls() {
		$this->start_controls_section(
			'Onair_Elementor_section_query_global',
			[
				'label' => esc_html__( 'Query', 'onair-elementor' ),
			]
		);	

			$this->add_control(
				'post_type',
				[
					'label' => esc_html__( 'Post type', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						"post" => esc_html__( "Posts", 'onair' ),
						"podcast" => esc_html__( "Podcast", 'onair' ),
						'event' => esc_html__( "Events", 'onair' ),
						'members' => esc_html__( "Team members", 'onair' ),
						'chart' => esc_html__( "Charts", 'onair' ),
					]
				]
			);


			
			$this->add_responsive_control(
				'onair-captionsize',
				[
					'label' => esc_html__( 'Caption size', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 12,
							'max' => 60,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors' => [
						'{{WRAPPER}} .onair-post__title  ' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);
			$this->add_control(
				'tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => Onair_Elementor_get_terms_array()
				]
			);
			$this->add_control(
				'tax_filter_exc',
				[
					'label' => esc_html__( 'Exclude by category', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => Onair_Elementor_get_terms_array()
				]
			);

			$this->add_control(
				'e_loadmore',
				[
					'label' => esc_html__( "Load more button", "onair" ),
					'type' => Controls_Manager::SWITCHER,
				]
			);
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('tax_filter', $atts)){
			if(is_array($atts['tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['tax_filter']);
			}
		}
		if(array_key_exists('tax_filter_exc', $atts)){
			if(is_array($atts['tax_filter_exc'])) {
				$atts['tax_filter_exc'] = implode(',', $atts['tax_filter_exc']);
			}
		}

		if(function_exists('onair_template_post_inline')){
			echo onair_template_post_inline( $atts );
		}
	}
	protected function content_template() {}
}