<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Qantum Themes SL
 * @package  Elementor OnAir
 * @version  1.0.0
 */


namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class OnairElementorPostSlider extends Widget_Base {
	public function get_name() {
		return 'onair-elementor-post-slider'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Post slider', 'onair-elementor' );
	}
	public function get_icon() {
		return 'onair-elementor-icons icon-prel-post-slider';
	}
	public function get_categories() {
		return [ 'aaa-onair' ]; // needs to be registered in _plugin.php
	}
	// Javascript
		/**
	 * @since version PR.2.3.0 loaded from minified scripts.
	 * To unse unminified, edit _plugin.php line 53 $use_minified_script = true;
	 * 
	 * 
	 * */
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'onair-elementor-post-slider', plugins_url( '/post-slider.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'onair-elementor-post-slider' ];
	}


	protected function register_controls() {


		
		/**
		 * ======================================
		 * Section:
		 * Query parameters
		 * ======================================
		 */
		
		$this->start_controls_section(
			'Onair_Elementor_section_query_global',
			[
				'label' => esc_html__( 'Query', 'onair-elementor' ),
			]
		);

			$this->add_control(
				'posttype',
				[
					'label' => esc_html__( 'Post type', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						"post" => esc_html__( "Post", 'onair' ),
						"chart" => esc_html__( "Chart", 'onair' ),
						"podcast" => esc_html__( "Podcast", 'onair' ),
						'members' => esc_html__( "Team member", 'onair' ),
						'event' => esc_html__( "Event", 'onair' ),
					]
				]
			);

			$this->add_control(
				'hideold',
				[
					'label' => esc_html__( 'Hide past events', 'plugin-domain' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Hide', 'your-plugin' ),
					'label_off' => esc_html__( 'Show', 'your-plugin' ),
					'return_value' => 'true',
					'default' => false,
					'condition' => [
						'posttype' => 'event'
					],
				]
			);
			

			$this->add_control(
				'tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => Onair_Elementor_get_terms_array()
				]
			);
			$this->add_control(
				'tax_filter_exc',
				[
					'label' => esc_html__( 'Exclude by category', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => Onair_Elementor_get_terms_array()
				]
			);
			// Important::::::::::::::::::::::::::::::::::::
			// Fields added by query-fields.php
			// :::::::::::::::::::::::::::::::::::::::::::::
		$this->end_controls_section();
	}
	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();

		$atts['onair_elementor'] = true;
		if(array_key_exists('tax_filter', $atts)){
			if(is_array($atts['tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['tax_filter']);
			}
		}
		if(array_key_exists('tax_filter_exc', $atts)){
			if(is_array($atts['tax_filter_exc'])) {
				$atts['tax_filter_exc'] = implode(',', $atts['tax_filter_exc']);
			}
		}

		if(function_exists('qantumthemes_slideshow_single')){
			echo qantumthemes_slideshow_single( $atts );
		}
	}
	protected function content_template() {}
}