<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Qantum Themes SL
 * @package  Elementor OnAir
 * @version  1.0.0
 */


namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class OnairElementorRadiofeed extends Widget_Base {
	public function get_name() {
		return 'onair-elementor-radiofeed'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Radio feed titles', 'onair-elementor' );
	}
	public function get_icon() {
		return 'onair-elementor-icons icon-prel-radio-feed';
	}
	public function get_categories() {
		return [ 'aaa-onair' ]; // needs to be registered in _plugin.php
	}

	// Javascript
		/**
	 * @since version PR.2.3.0 loaded from minified scripts.
	 * To unse unminified, edit _plugin.php line 53 $use_minified_script = true;
	 * 
	 * 
	 * */
	 public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'onair-elementor-radiofeed', plugins_url( '/radiofeed.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'onair-elementor-radiofeed' ];
	}


	protected function register_controls() {
		$this->start_controls_section(
			'section_button',
			[
				'label' => esc_html__( 'Settings', 'onair-elementor' ),
			]
		);
			$this->add_control(
				'intro',
				[
					'label' => esc_html__( 'Important Note', 'onair-elementor' ),
					'raw' => __( '<h2><strong>This text becomes visible only after playing a radio stream with valid song feed details.</strong></h2>', 'onair-elementor' ),
					'type' => Controls_Manager::RAW_HTML,
				]
			);


			$this->add_control(
				'onair-txt-song-color',
				[
					'label' => esc_html__( 'Song color', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qtFeedPlayerTrack' => 'color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'onair-txt-artist-color',
				[
					'label' => esc_html__( 'Artist color', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qtFeedPlayerAuthor' => 'color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'onair-txt-typo',
					'label' => __( 'Song typography','onair-elementor'),
					'scheme' => Typography::TYPOGRAPHY_1,
					'selector' => '{{WRAPPER}} .qtFeedPlayerTrack'
				]
			);
			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'onair-txt-artisttypo',
					'label' => __( 'Artist typography','onair-elementor'),
					'scheme' => Typography::TYPOGRAPHY_1,
					'selector' => '{{WRAPPER}} .qtFeedPlayerAuthor'
				]
			);

			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'onair-elementor' ),
					'default' => esc_html__( 'Now playing:', 'onair-elementor' ),
					'description' => esc_html__( 'Label for the song title', 'onair-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			
			$this->add_control(
				'tag',
				[
					'label' 	=> esc_html__( 'Container tag', 'onair-elementor' ),
					'type' 		=> \Elementor\Controls_Manager::SELECT,
					'default' 	=> 'p',
					'options' 	=>[
						'' 			=> esc_html__('No container', 'onair-elementor'), 
						'h1' 		=> esc_html__('Heading 1', 'onair-elementor'), 
						'h2' 		=> esc_html__('Heading 2', 'onair-elementor'), 
						"h3" 		=> esc_html__('Heading 3', 'onair-elementor'), 
						"h4" 		=> esc_html__('Heading 4', 'onair-elementor'), 
						"h5" 		=> esc_html__('Heading 5', 'onair-elementor'), 
						"h6" 		=> esc_html__('Heading 6', 'onair-elementor'), 
						"p" 		=> esc_html__('Paragraph', 'onair-elementor'), 
					]
				]
			);
			$this->add_control(
				'align',
				[
					'label' 	=> esc_html__( 'Align', 'onair-elementor' ),
					'type' 		=> \Elementor\Controls_Manager::SELECT,
					'default' => 'center',
					'options' =>[
						''	=> esc_html__('default', 'onair' ),
						'center'	=> esc_html__('center', 'onair' ),
						'left'		=> esc_html__('left', 'onair' ),
						'right'		=> esc_html__('right', 'onair' ),
						'inline'	=> esc_html__('inline', 'onair' ),
					]
				]
			);
			

			
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
	
		$atts = $this->get_settings_for_display();
		extract( shortcode_atts( array(
			'title' => 'Now playing:',
			'tag' => 'p',
			'align' => 'center',
			'class' => '',
			'marquee' => '1'
		), $atts ) );

		if(!$tag){
			$tag = 'p';
		}
		$align = 'qt-'.$align .' align'.$align;
		ob_start();
		?>
			<?php echo '<'.esc_attr($tag); ?> class="onair-now_on_air_text onair-feed  <?php echo esc_attr($class.' '.$align); ?>">
			<?php echo esc_html($title); ?> <span class="qtFeedPlayerTrack">Loading title</span> <br> <span class="qtFeedPlayerAuthor ">Loading artist</span>
			<?php echo '</'.esc_attr($tag).'>'; ?>
		<?php
		echo ob_get_clean();
	}
	
	protected function content_template() {}
}