<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Qantum Themes SL
 * @package  Elementor OnAir
 * @version  1.0.1
 */


namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class OnairElementorSocialIcons extends Widget_Base {
	public function get_name() {
		return 'onair-elementor-socialicons'; // need to use same ID in the script js
	}
	public function get_title() {
		return __( 'Social Icons', 'onair-elementor' );
	}
	public function get_icon() {
		return 'onair-elementor-icons icon-prel-social';
	}
	public function get_categories() {
		return [ 'onair-elementor' ]; // needs to be registered in _plugin.php
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_icons',
			[
				'label' => __( 'Icons', 'onair-elementor' ),
			]
		);	
			$this->add_control(
				'text',
				[
					'label' => esc_html__( 'Button label', 'elementor-onair' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__('Click here', 'elementor-onair')
				]
			);
			$this->add_control(
				'link',
				[
					'label' => esc_html__( 'Button link', 'elementor-onair' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'target',
				[
					'label' => esc_html__( 'Button target', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						'' => esc_html__('Default', 'elementor-onair'),
						'_blank' => esc_html__('New tab', 'elementor-onair')
					]
				]
			);
			$this->add_control(
				'style',
				[
					'label' => esc_html__( 'Style', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						"onair-btn-default" 	=> 	esc_html__( "Default",'onair-elementor'),
						"onair-btn-primary" 	=> 	esc_html__( "Primary",'onair-elementor'),
						"onair-btn__white" 	=> 	esc_html__( "White",'onair-elementor'),
						"onair-btn__bold" 	=> 	esc_html__( "Bold",'onair-elementor'),
						"onair-btn__txt" 	=> 	esc_html__( "Text only",'onair-elementor')
					]
				]
			);
			$this->add_control(
				'alignment',
				[
					'label' => esc_html__( 'Alignment', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						'' => esc_html__( "Default", "onair"),
						'alignleft' 	=>	esc_html__( "Left", 'onair-elementor'),
						'alignright'	=>	esc_html__( "Right", 'onair-elementor'),
						'aligncenter'	=>	esc_html__( "Center", 'onair-elementor'),
					]
				]
			);
			$this->add_control(
				'icon',
				[
					'label' => esc_html__( 'Icon', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => false,
					'options' =>[
						false				=> esc_html__( 'No icon', 'onair-elementor' ),
						'android' 			=> esc_html__( 'Android', 'onair-elementor' ),
						'amazon' 			=> esc_html__( 'Amazon', 'onair-elementor' ),
						'beatport' 			=> esc_html__( 'Beatport', 'onair-elementor' ),
						'blogger' 			=> esc_html__( 'Blogger', 'onair-elementor' ),
						'facebook' 			=> esc_html__( 'Facebook', 'onair-elementor' ),
						'flickr' 			=> esc_html__( 'Flickr', 'onair-elementor' ),
						'instagram' 		=> esc_html__( 'Instagram', 'onair-elementor' ),
						'itunes' 			=> esc_html__( 'Itunes', 'onair-elementor' ),
						'juno' 				=> esc_html__( 'Juno', 'onair-elementor' ),
						'kuvo' 				=> esc_html__( 'Kuvo', 'onair-elementor' ),
						'linkedin' 			=> esc_html__( 'Linkedin', 'onair-elementor' ),
						'trackitdown' 		=> esc_html__( 'Trackitdown', 'onair-elementor' ),
						'spotify' 			=> esc_html__( 'Spotify', 'onair-elementor' ),
						'soundcloud' 		=> esc_html__( 'Soundcloud', 'onair-elementor' ),
						'snapchat' 			=> esc_html__( 'Snapchat', 'onair-elementor' ),
						'skype' 			=> esc_html__( 'Skype', 'onair-elementor' ),
						'reverbnation' 		=> esc_html__( 'Reverbnation', 'onair-elementor' ),
						'residentadvisor' 	=> esc_html__( 'Resident Advisor', 'onair-elementor' ),
						'pinterest' 		=> esc_html__( 'Pinterest', 'onair-elementor' ),
						'myspace' 			=> esc_html__( 'Myspace', 'onair-elementor' ),
						'mixcloud' 			=> esc_html__( 'Mixcloud', 'onair-elementor' ),
						'rss' 				=> esc_html__( 'RSS', 'onair-elementor' ),
						'tiktok' 			=> esc_html__( 'TikTok', 'onair-elementor' ),
						'twitter' 			=> esc_html__( 'Twitter', 'onair-elementor' ),
						'twitch' 			=> esc_html__( 'Twitch', 'onair-elementor' ),
						'vimeo' 			=> esc_html__( 'Vimeo', 'onair-elementor' ),
						'vk' 				=> esc_html__( 'VK.com', 'onair-elementor' ),
						'youtube' 			=> esc_html__( 'YouTube', 'onair-elementor' ),
						'whatsapp' 			=> esc_html__( 'Whatsapp', 'onair-elementor' ),
					]
				]
			);
		$this->end_controls_section();

		$this->start_controls_section(
			'onair_section_button_design',
			[
				'label' => esc_html__( 'Design', 'elementor-onair' ),
			]
		);

			$this->add_responsive_control(
				'btn-size',
				[
					'label' => esc_html__( 'Size', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 120,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors' => [
						'{{WRAPPER}} .onair-btn' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'pr_padding',
				[
					'label' => __( 'Padding', 'kentha-elementor' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'default' =>[
						'isLinked' => false,
						],
					'selectors' => [
						'{{WRAPPER}} .onair-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);


			$this->add_responsive_control(
				'btn-radius',
				[
					'label' => esc_html__( 'Border-radius', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 300,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors' => [
						'{{WRAPPER}} .onair-btn' => 'border-radius: {{SIZE}}{{UNIT}};',
					],
				]
			);
		$this->end_controls_section();

		/**
		 * Colors
		 */
		$this->start_controls_section(
			'section_button_col',
			[
				'label' => esc_html__( 'Colors', 'elementor-onair' ),
			]
		);
			$this->add_control(
				'onair-btn-bg',
				[
					'label' => esc_html__( 'Background', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .onair-btn' => 'background-color: {{VALUE}} !important;',
					],
				]
			);
			$this->add_control(
				'onair-btn-txt',
				[
					'label' => esc_html__( 'Text color', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .onair-btn' => 'color: {{VALUE}} !important;',
					]
				]
			);

			$this->add_control(
				'onair-btn-icon',
				[
					'label' => esc_html__( 'Icon color', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} i' => 'color: {{VALUE}} !important;',
					],
					'condition' => [
						'onair_showicon' => '1',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'onair-btn-border',
					'label' => __( 'Border', 'plugin-domain' ),
					'selector' => '{{WRAPPER}} .onair-btn',
				]
			);

			

		$this->end_controls_section();

		/**
		 * Colors hover
		 */
		$this->start_controls_section(
			'section_button_col_h',
			[
				'label' => esc_html__( 'Colors hover', 'elementor-onair' ),
			]
		);
			$this->add_control(
				'onair-btn-bgh',
				[
					'label' => esc_html__( 'Background hover', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .onair-btn:hover' => 'background-color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'onair-btn-bch',
				[
					'label' => esc_html__( 'Border hover', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .onair-btn:hover' => 'border-color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'onair-btn-txthov',
				[
					'label' => esc_html__( 'Text color hover', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .onair-btn:hover' => 'color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'onair-btn-iconh',
				[
					'label' => esc_html__( 'Icon color hover', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .onair-btn:hover .onair-btn__icon ' => 'color: {{VALUE}} !important;',
					],
					'condition' => [
						'onair_showicon' => '1',
					],
				]
			);

		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		if(function_exists('onair_template_socialicons_shortcode')){
			echo onair_template_socialicons_shortcode( $this->get_settings_for_display() );
		}
	}

	
	protected function content_template() {}
}