<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Qantum Themes SL
 * @package  Elementor OnAir
 * @version  2.2.0
 */


namespace OnairElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class OnairElementorUpcomingShowsCarousel extends Widget_Base {
	public function get_name() {
		return 'onair-elementor-upcoming-shows-carousel'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Upcoming shows carousel', 'onair-elementor' );
	}
	public function get_icon() {
		return 'onair-elementor-icons icon-prel-shows-carousel';
	}
	public function get_categories() {
		return [ 'aaa-onair' ]; // needs to be registered in _plugin.php
	}
	// Javascript
		/**
	 * @since version PR.2.3.0 loaded from minified scripts.
	 * To unse unminified, edit _plugin.php line 53 $use_minified_script = true;
	 * 
	 * 
	 * */
	 public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'onair-elementor-upcoming-shows-carousel', plugins_url( '/upcoming-shows-carousel.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'onair-elementor-upcoming-shows-carousel' ];
	}
	protected function register_controls() {
		/**
		 * ======================================
		 * Section:
		 * Slider parameters
		 * ======================================
		 */
		$this->start_controls_section(
			'Onair_Elementor_section_carousel_global',
			[
				'label' => esc_html__( 'Settings', 'onair-elementor' ),
			]
		);

			$this->add_responsive_control(
				'onair-captionsize',
				[
					'label' => esc_html__( 'Caption size', 'elementor-onair' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 15,
							'max' => 90,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors' => [
						'{{WRAPPER}} .qt-title  ' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);
		// Important::::::::::::::::::::::::::::::::::::
		// Fields added by carousel-fields.php
		// :::::::::::::::::::::::::::::::::::::::::::::
		$this->end_controls_section();

		/**
		 * ======================================
		 * Section:
		 * Query parameters
		 * ======================================
		 */
		
		$this->start_controls_section(
			'Onair_Elementor_query',
			[
				'label' => esc_html__( 'Filters', 'onair-elementor' ),
			]
		);
			/**
			 * since 2.2.0
			 * Added option to hide current show
			 */
			$this->add_control(
				'pr_hide_currentshow',
				[
					'label' => esc_html__( 'Hide current show', 'onair-elementor' ),
					'type' => Controls_Manager::SWITCHER,
					'return_value' => 'true',
				]
			);

			$this->add_control(
				'quantity',
				[
					'label' => esc_html__( 'Max items', 'onair-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'min' => 3,
					'max' => 16,
					'step' => 1,
					'default' => 6,
				]
			);
			$this->add_control(
				'tax_filter',
				[
					'label' => esc_html__( 'Schedule filters', 'onair-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'options' => Onair_Elementor_get_terms_array( 'schedulefilter' )
				]
			);

			// Important::::::::::::::::::::::::::::::::::::
			// Fields added by query-fields.php
			// :::::::::::::::::::::::::::::::::::::::::::::
		$this->end_controls_section();
	}
	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('tax_filter', $atts)){
			if(is_array($atts['tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['tax_filter']);
			}
		}
		if(function_exists('qantumthemes_upcoming_carousel')){
			echo qantumthemes_upcoming_carousel( $atts );
		}
	}
	protected function content_template() {}
}